extract_tables_from_query_checked

Function extract_tables_from_query_checked 

pub fn extract_tables_from_query_checked(
    query: &SqlOrTql,
) -> Option<impl Iterator<Item = ObjectName>>
Walk through a Query and extract its referenced tables, returning None if any table reference cannot be resolved statically.