pub fn extract_tables_from_statement_checked(
stmt: &Statement,
) -> Option<impl Iterator<Item = ObjectName>>Expand description
Walks through a Statement and extracts all referenced tables, returning
None if any table reference cannot be resolved statically.